@@ -244,15 +244,17 @@ class JsonObject:
         return None
 
     def __dataframe_values__(self):
-        return [v.to_dataframe(recursive=True) if isinstance(v, (JsonList, JsonObject)) else v for v in self.get_values()]
+        return [v.to_dataseries(recursive=True) if isinstance(v, JsonObject) else v.to_dataframe(recursive=True) if isinstance(v, JsonList) else v for v in self.get_values()]
 
-    def to_dataframe(self, recursive: bool = False):
-        from pandas import DataFrame
+    def to_dataseries(self, recursive: bool = False):
+        import pandas as pd
         columns = self.get_columns()
         if recursive:
-            return DataFrame([self.__dataframe_values__()], columns=columns)
+            values = self.__dataframe_values__()
         else:
-            return DataFrame([self.get_values()], columns=columns)
+            values = self.get_values()
+
+        return pd.core.series.Series(dict(zip(columns,values)))
 
 
 class SortOrder:
